@@ -1,6 +1,6 @@
 #ifndef CALC_H
 #define CALC_H
 
-double qcalculate (QString expression);
+double qcalculate (const QString &expression);
 
 #endif // CALC_H
