@@ -3,11 +3,14 @@ this code is Public Domain
 */
 
 
-#include <QtCore>
-
-
-#include "calendar.h"
 #include "utils.h"
+#include "calendar.h"
+#include "math.h"
+
+#include <QDateTime>
+#include <QDate>
+#include <QPainter>
+#include <QTextCharFormat>
 
 inline int tropical_year (int year)
 {
@@ -295,4 +298,3 @@ int moon_phase_by_algo (int v, int year, int month, int day)
 
  return r;
 }
-
