@@ -39,13 +39,19 @@ code from qwriter:
 */
 
 
-#include <QtGui>
-#include <QDomDocument>
 
 #include "document.h"
 #include "utils.h"
 #include "gui_utils.h"
 
+//#include <QtGui>
+
+//#include <QPlainTextEdit>
+
+#include <QDomDocument>
+#include <QLabel>
+#include <QPainter>
+
 
 QSettings *settings;
 
