@@ -41,14 +41,22 @@ code from qwriter:
 #ifndef DOCUMENT_H
 #define DOCUMENT_H
 
-#include <QtGui>
 
 #include "logmemo.h"
 #include "tio.h"
-
 #include "todo.h"
 
 
+#include <QStatusBar>
+#include <QMainWindow>
+#include <QTabWidget>
+#include <QPlainTextEdit>
+//#include <QList>
+//#include <QString>
+#include <QSyntaxHighlighter>
+
+
+
 
 class LineNumberArea;
 class document_holder;
