@@ -22,6 +22,11 @@
 #include "utils.h"
 #include "logmemo.h"
 
+#include <QFileInfoList>
+#include <QUrl>
+#include <QMimeData>
+
+
 
 void CFMan::dir_up()
 {
