@@ -1,7 +1,15 @@
 #ifndef GUI_UTILS_H
 #define GUI_UTILS_H
 
-#include <QtGui>
+//#include <QtGui>
+
+#include <QObject>
+#include <QMenu>
+#include <QLineEdit>
+#include <QSpinBox>
+#include <QComboBox>
+#include <QBoxLayout>
+
 
 
 void create_menu_from_list (QObject *handler,
@@ -24,8 +32,8 @@ QImage image_scale_by (const QImage &source,
                        Qt::TransformationMode mode);
 
 
-QString mod_to_string (Qt::KeyboardModifiers k);
-QString keycode_to_string (int k);
+//QString mod_to_string (Qt::KeyboardModifiers k);
+//QString keycode_to_string (int k);
 
 QLineEdit* new_line_edit (QBoxLayout *layout, const QString &label, const QString &def_value);
 QSpinBox* new_spin_box (QBoxLayout *layout, const QString &label, int min, int max, int value, int step = 1);
@@ -37,4 +45,6 @@ QComboBox* new_combobox (QBoxLayout *layout,
                          const QString &def_value);
 
 
+
+
 #endif // GUI_UTILS_H
