@@ -1,6 +1,12 @@
 #include "img_viewer.h"
 #include "utils.h"
 
+#include <QVBoxLayout>
+#include <QCryptographicHash>
+#include <QDir>
+#include <QImageReader>
+#include <QKeyEvent>
+
 
 CImgViewer::CImgViewer (QObject *parent): QObject (parent)
 {
@@ -47,8 +53,8 @@ QString CImgViewer::get_the_thumb_name (const QString &img_fname)
 {
  
 //FIXME: add OS2 tweak!
-#ifndef Q_WS_WIN
- 
+#if !defined(Q_WS_WIN) || !defined(Q_OS_OS2)
+
   QCryptographicHash h (QCryptographicHash::Md5); 
   
   QString uri (img_fname);
