@@ -1,7 +1,13 @@
 #ifndef IMG_VIEWER_H
 #define IMG_VIEWER_H
 
-#include <QtGui>
+//#include <QtGui>
+
+#include <QObject>
+#include <QWidget>
+#include <QFileInfoList>
+#include <QLabel>
+
 
 class CViewerWindow: public QWidget
 {  
