@@ -23,7 +23,7 @@
 #define RVLN_H
 
 
-#include <QtGui>
+//#include <QtGui>
 
 #include "document.h"
 #include "fman.h"
@@ -39,6 +39,23 @@
 #endif
 
 
+#include <QListWidget>
+#include <QComboBox>
+#include <QProgressBar>
+#include <QCheckBox>
+#include <QSpinBox>
+#include <QFontComboBox>
+#include <QSessionManager>
+#include <QApplication>
+#include <QCoreApplication>
+#include <QSplitter>
+#include <QTextBrowser>
+
+#ifdef PRINTER_ENABLE
+
+#include <QPrinter>
+
+#endif
 
 
 class CMarkupPair: public QObject
@@ -149,6 +166,9 @@ public:
   int idx_tab_fman;
   int idx_tab_learn;
   
+  int idx_tab_keyboard;
+
+
   int idx_prev;
   
   int fman_find_idx;
@@ -184,8 +204,14 @@ public:
   QString man_search_value;
 
   QString markup_mode;
+
+#ifdef PRINTER_ENABLE
+
+
   QPrinter printer;
 
+#endif
+
 //  QSettings *settings;
 
   QString opt_shortcuts_string_to_find;
@@ -254,6 +280,8 @@ public:
   QComboBox *cmb_output_image_fmt;
   QCheckBox *cb_output_image_flt;
 
+  QComboBox *cmb_ui_langs;
+
   QSpinBox *spb_img_quality;
   QCheckBox *cb_zip_after_scale;
 
@@ -306,6 +334,7 @@ main window callbacks
   void cb_button_saves_as();
 
   void pageChanged (int index);
+  void tab_options_pageChanged (int index);
 
   void file_print();
 
@@ -457,7 +486,7 @@ main window callbacks
 
 #ifdef ASPELL_ENABLE
 
-#if defined(Q_WS_WIN) || defined (_OS_OS2)
+#if defined(Q_WS_WIN) || defined (Q_OS_OS2)
    void pb_choose_aspell_path_clicked();
 #endif
 
@@ -560,7 +589,9 @@ main window callbacks
 prefs window callbacks
 *************************/
 
-  
+  void cmb_ui_langs_currentIndexChanged (const QString &text);
+
+
   void cmb_ui_tabs_currentIndexChanged (int i);
   void cmb_docs_tabs_currentIndexChanged (int i);
 
