@@ -23,6 +23,101 @@
 #include "utils.h"
 #include "gui_utils.h"
 
+#include <QString>
+
+
+#include <QKeyEvent>
+#include <QAction>
+#include <QStringList>
+#include <QKeySequence>
+
+
+
+
+QString mod_to_string (Qt::KeyboardModifiers k)
+{
+  QString s;
+
+  if (k & Qt::ShiftModifier)
+     s += "Shift+";
+
+  if (k & Qt::ControlModifier)
+     s += "Ctrl+";
+
+  if (k & Qt::AltModifier)
+     s += "Alt+";
+
+  if (k & Qt::MetaModifier)
+     s+= "Meta+";
+
+  return s;
+}
+
+
+QString keycode_to_string (int k)
+{
+ // return QKeySequence(k).toString();
+
+  QString s;
+
+  switch (k)
+         {
+          case Qt::Key_F1:
+                          s = "F1";
+                          break;
+
+          case Qt::Key_F2:
+                          s = "F2";
+                          break;
+
+          case Qt::Key_F3:
+                          s = "F3";
+                          break;
+
+          case Qt::Key_F4:
+                          s = "F4";
+                          break;
+
+          case Qt::Key_F5:
+                          s = "F5";
+                          break;
+
+          case Qt::Key_F6:
+                          s = "F6";
+                          break;
+
+          case Qt::Key_F7:
+                          s = "F7";
+                          break;
+
+          case Qt::Key_F8:
+                          s = "F8";
+                          break;
+
+          case Qt::Key_F9:
+                          s = "F9";
+                          break;
+
+          case Qt::Key_F10:
+                          s = "F10";
+                          break;
+
+          case Qt::Key_F11:
+                          s = "F11";
+                          break;
+
+          case Qt::Key_F12:
+                          s = "F12";
+                          break;
+
+          default:
+                  s = QChar (k);
+         }
+
+  return s;
+}
+
+
 
 CShortcuts::CShortcuts (QWidget *widget)
 {
