@@ -28,6 +28,10 @@
 
 #include "utils.h"
 
+#include <QTextCodec>
+#include <QDir>
+
+
 
 #ifdef ASPELL_ENABLE
 
