@@ -29,7 +29,11 @@
 #include <hunspell/hunspell.hxx>
 #endif
 
-#include <QtCore>
+//#include <QtCore>
+
+#include <QDebug>
+#include <QString>
+#include <QStringList>
 
 
 class ASpellchecker
