@@ -35,7 +35,8 @@ some code is taken from Scribus::util.cpp:
 
 
 
-#include <QtCore>
+#include <QString>
+#include <QMap>
 
 #include "textproc.h"
 #include "utils.h"
