@@ -1,8 +1,8 @@
 #ifndef TIO_H
 #define TIO_H
 
-#include <QtCore>
-#include "QtXml"
+//#include <QtCore>
+#include <QtXml>
 
 
 class CSignaturesList: public QObject
