@@ -108,10 +108,6 @@ Do you want to save your changes?</source>
         <source>edit</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>&lt;b&gt;TEA %1 @ http://tea-editor.sourceforge.net&lt;/b&gt;&lt;br&gt;by Peter Semiletov (peter.semiletov@gmail.com)&lt;br&gt;read the Manual under the &lt;i&gt;learn&lt;/i&gt; tab!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Charset</source>
         <translation>Zeichensatz</translation>
@@ -985,10 +981,6 @@ Do you want to overwrite?</source>
         <source>chars: %1&lt;br&gt;chars without spaces: %2&lt;br&gt;lines: %3&lt;br&gt;author&apos;s sheets: %4</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>%1 %2 kbytes&lt;br&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>%1 is not found&lt;br&gt;</source>
         <translation type="unfinished"></translation>
@@ -1312,18 +1304,6 @@ opera=opera %s</source>
         <source>Years</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Days between two dates</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Set first date</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Set second date</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Remove day record</source>
         <translation type="unfinished"></translation>
@@ -1336,10 +1316,6 @@ opera=opera %s</source>
         <source>Miscellaneous</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>todo</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Enter your daily notes here.</source>
         <translation type="unfinished"></translation>
@@ -1359,5 +1335,169 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
         <source>Aspell directory</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Rename selected file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select the file name first!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Labels</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Refresh labels</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add user font</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label starts with: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label ends with: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select font</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Fonts (*.ttf *.otf)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>C++ template</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>C template</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>List ZIP content</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unpack ZIP to current directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ZIP unpacking: file names charset</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ZIP packing: file names charset</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 kbytes %2 &lt;br&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Shortcut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Go to current date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>UI tabs align</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Right</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Left</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Documents tabs align</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bottom</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 is processed and saved</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;b&gt;TEA %1 @ http://tea-editor.sourceforge.net&lt;/b&gt;&lt;br&gt;by Peter Semiletov (peter.semiletov@gmail.com)&lt;br&gt;read the Manual under the &lt;i&gt;Learn&lt;/i&gt; tab!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set as storage file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy to storage file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start/stop capture clipboard to storage file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Moon mode on/off</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mark first date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mark last date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Calculate moon days between dates</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Number of days between two dates</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Northern hemisphere</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Moon phase algorithm</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>dates</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Trigonometric 2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Trigonometric 1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Conway</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Leueshkanov</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
