@@ -4,7 +4,14 @@ Peter Semiletov
 */
 
 
-#include <QtGui>
+#include <QTextStream>
+#include <QDebug>
+#include <QDir>
+#include <QImageReader>
+#include <QImage>
+
+
+
 #include "utils.h"
 
 
